<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>FFVideoFactory</name>
    <message>
        <location filename="../ffvideofactory.cpp" line="41"/>
        <source>FFmpeg Video Plugin</source>
        <translation>Estensione video FFmpeg</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="45"/>
        <source>Video Files</source>
        <translation>File video</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="191"/>
        <source>About FFVideo Plugin</source>
        <translation>Informazioni sull&apos;estensione FFVideo</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="192"/>
        <source>FFmpeg-based video plugin for Qmmp</source>
        <translation>Estensione video basata su FFmpeg per Qmmp</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="193"/>
        <source>Compiled against:</source>
        <translation>Compilata con:</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="202"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Autore: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FFVideoMetaDataModel</name>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Dimensione file</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <source>Bitrate</source>
        <translation>Bit al secondo</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <source>Audio bitrate</source>
        <translation>Bit al secondo audio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Audio sample rate</source>
        <translation>Frequenza di campionamento audio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <location filename="../ffvideometadatamodel.cpp" line="86"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="73"/>
        <location filename="../ffvideometadatamodel.cpp" line="75"/>
        <source>Audio channels</source>
        <translation>Canali audio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="79"/>
        <source>Audio format</source>
        <translation>Formato audio</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="85"/>
        <source>Video size</source>
        <translation>Dimensione video</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="86"/>
        <source>Video bitrate</source>
        <translation>Bit al secondo video</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="89"/>
        <source>Video format</source>
        <translation>Formato video</translation>
    </message>
</context>
<context>
    <name>VideoWindow</name>
    <message>
        <location filename="../videowindow.cpp" line="40"/>
        <source>FFmpeg Video</source>
        <translation>Video FFmpeg</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <location filename="../videowindow.cpp" line="51"/>
        <location filename="../videowindow.cpp" line="70"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <location filename="../videowindow.cpp" line="51"/>
        <source>Space</source>
        <translation>Spazio</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="47"/>
        <location filename="../videowindow.cpp" line="52"/>
        <source>&amp;Stop</source>
        <translation>&amp;Ferma</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="47"/>
        <location filename="../videowindow.cpp" line="52"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="49"/>
        <location filename="../videowindow.cpp" line="54"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Schermo intero</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="49"/>
        <location filename="../videowindow.cpp" line="54"/>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="75"/>
        <source>&amp;Resume</source>
        <translation>&amp;Ripristina</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="80"/>
        <source>&amp;Play</source>
        <translation>Ri&amp;produci</translation>
    </message>
</context>
</TS>
